==> config-api-0.3.8-sources.jar: org/wildfly/swarm/config/undertow/servlet_container/JspSetting.java <==
package org.wildfly.swarm.config.undertow.servlet_container;

import org.wildfly.swarm.config.runtime.Implicit;
import org.wildfly.swarm.config.runtime.ResourceType;
import org.wildfly.swarm.config.runtime.ModelNodeBinding;
/**
 * JSP container configuration.
 */
@ResourceType("setting")
@Implicit
public class JspSetting {

	private String key;
	private Integer checkInterval;
	private Boolean development;
	private Boolean disabled;
	private Boolean displaySourceFragment;
	private Boolean dumpSmap;
	private Boolean errorOnUseBeanInvalidClassAttribute;
	private Boolean generateStringsAsCharArrays;
	private String javaEncoding;
	private Boolean keepGenerated;
	private Boolean mappedFile;
	private Integer modificationTestInterval;
	private Boolean optimizeScriptlets;
	private Boolean recompileOnFail;
	private String scratchDir;
	private Boolean smap;
	private String sourceVm;
	private Boolean tagPooling;
	private String targetVm;
	private Boolean trimSpaces;
	private Boolean xPoweredBy;

	public JspSetting() {
		this.key = "jsp";
	}

	public String getKey() {
		return this.key;
	}

	/**
	 * Check interval for JSP updates using a background thread.
	 */
	@ModelNodeBinding(detypedName = "check-interval")
	public Integer checkInterval() {
		return this.checkInterval;
	}

	/**
	 * Check interval for JSP updates using a background thread.
	 */
	@SuppressWarnings("unchecked")
	public JspSetting checkInterval(Integer value) {
		this.checkInterval = value;
		return (JspSetting) this;
	}

	/**
	 * Enable Development mode which enables reloading JSP on-the-fly
	 */
	@ModelNodeBinding(detypedName = "development")
	public Boolean development() {
		return this.development;
	}

	/**
	 * Enable Development mode which enables reloading JSP on-the-fly
	 */
	@SuppressWarnings("unchecked")
	public JspSetting development(Boolean value) {
		this.development = value;
		return (JspSetting) this;
	}

	/**
	 * Enable the JSP container.
	 */
	@ModelNodeBinding(detypedName = "disabled")
	public Boolean disabled() {
		return this.disabled;
	}

	/**
	 * Enable the JSP container.
	 */
	@SuppressWarnings("unchecked")
	public JspSetting disabled(Boolean value) {
		this.disabled = value;
		return (JspSetting) this;
	}

	/**
	 * When a runtime error occurs, attempts to display corresponding JSP source fragment
	 */
	@ModelNodeBinding(detypedName = "display-source-fragment")
	public Boolean displaySourceFragment() {
		return this.displaySourceFragment;
	}

	/**
	 * When a runtime error occurs, attempts to display corresponding JSP source fragment
	 */
	@SuppressWarnings("unchecked")
	public JspSetting displaySourceFragment(Boolean value) {
		this.displaySourceFragment = value;
		return (JspSetting) this;
	}

	/**
	 * Write SMAP data to a file.
	 */
	@ModelNodeBinding(detypedName = "dump-smap")
	public Boolean dumpSmap() {
		return this.dumpSmap;
	}

	/**
	 * Write SMAP data to a file.
	 */
	@SuppressWarnings("unchecked")
	public JspSetting dumpSmap(Boolean value) {
		this.dumpSmap = value;
		return (JspSetting) this;
	}

	/**
	 * Enable errors when using a bad class in useBean.
	 */
	@ModelNodeBinding(detypedName = "error-on-use-bean-invalid-class-attribute")
	public Boolean errorOnUseBeanInvalidClassAttribute() {
		return this.errorOnUseBeanInvalidClassAttribute;
	}

	/**
	 * Enable errors when using a bad class in useBean.
	 */
	@SuppressWarnings("unchecked")
	public JspSetting errorOnUseBeanInvalidClassAttribute(Boolean value) {
		this.errorOnUseBeanInvalidClassAttribute = value;
		return (JspSetting) this;
	}

	/**
	 * Generate String constants as char arrays.
	 */
	@ModelNodeBinding(detypedName = "generate-strings-as-char-arrays")
	public Boolean generateStringsAsCharArrays() {
		return this.generateStringsAsCharArrays;
	}

	/**
	 * Generate String constants as char arrays.
	 */
	@SuppressWarnings("unchecked")
	public JspSetting generateStringsAsCharArrays(Boolean value) {
		this.generateStringsAsCharArrays = value;
		return (JspSetting) this;
	}

	/**
	 * Specify the encoding used for Java sources.
	 */
	@ModelNodeBinding(detypedName = "java-encoding")
	public String javaEncoding() {
		return this.javaEncoding;
	}

	/**
	 * Specify the encoding used for Java sources.
	 */
	@SuppressWarnings("unchecked")
	public JspSetting javaEncoding(String value) {
		this.javaEncoding = value;
		return (JspSetting) this;
	}

	/**
	 * Keep the generated Servlets.
	 */
	@ModelNodeBinding(detypedName = "keep-generated")
	public Boolean keepGenerated() {
		return this.keepGenerated;
	}

	/**
	 * Keep the generated Servlets.
	 */
	@SuppressWarnings("unchecked")
	public JspSetting keepGenerated(Boolean value) {
		this.keepGenerated = value;
		return (JspSetting) this;
	}

	/**
	 * Map to the JSP source.
	 */
	@ModelNodeBinding(detypedName = "mapped-file")
	public Boolean mappedFile() {
		return this.mappedFile;
	}

	/**
	 * Map to the JSP source.
	 */
	@SuppressWarnings("unchecked")
	public JspSetting mappedFile(Boolean value) {
		this.mappedFile = value;
		return (JspSetting) this;
	}

	/**
	 * Minimum amount of time between two tests for updates, in seconds.
	 */
	@ModelNodeBinding(detypedName = "modification-test-interval")
	public Integer modificationTestInterval() {
		return this.modificationTestInterval;
	}

	/**
	 * Minimum amount of time between two tests for updates, in seconds.
	 */
	@SuppressWarnings("unchecked")
	public JspSetting modificationTestInterval(Integer value) {
		this.modificationTestInterval = value;
		return (JspSetting) this;
	}

	/**
	 * If JSP scriptlets should be optimised to remove string concatenation
	 */
	@ModelNodeBinding(detypedName = "optimize-scriptlets")
	public Boolean optimizeScriptlets() {
		return this.optimizeScriptlets;
	}

	/**
	 * If JSP scriptlets should be optimised to remove string concatenation
	 */
	@SuppressWarnings("unchecked")
	public JspSetting optimizeScriptlets(Boolean value) {
		this.optimizeScriptlets = value;
		return (JspSetting) this;
	}

	/**
	 * Retry failed JSP compilations on each request.
	 */
	@ModelNodeBinding(detypedName = "recompile-on-fail")
	public Boolean recompileOnFail() {
		return this.recompileOnFail;
	}

	/**
	 * Retry failed JSP compilations on each request.
	 */
	@SuppressWarnings("unchecked")
	public JspSetting recompileOnFail(Boolean value) {
		this.recompileOnFail = value;
		return (JspSetting) this;
	}

	/**
	 * Specify a different work directory.
	 */
	@ModelNodeBinding(detypedName = "scratch-dir")
	public String scratchDir() {
		return this.scratchDir;
	}

	/**
	 * Specify a different work directory.
	 */
	@SuppressWarnings("unchecked")
	public JspSetting scratchDir(String value) {
		this.scratchDir = value;
		return (JspSetting) this;
	}

	/**
	 * Enable SMAP.
	 */
	@ModelNodeBinding(detypedName = "smap")
	public Boolean smap() {
		return this.smap;
	}

	/**
	 * Enable SMAP.
	 */
	@SuppressWarnings("unchecked")
	public JspSetting smap(Boolean value) {
		this.smap = value;
		return (JspSetting) this;
	}

	/**
	 * Source VM level for compilation.
	 */
	@ModelNodeBinding(detypedName = "source-vm")
	public String sourceVm() {
		return this.sourceVm;
	}

	/**
	 * Source VM level for compilation.
	 */
	@SuppressWarnings("unchecked")
	public JspSetting sourceVm(String value) {
		this.sourceVm = value;
		return (JspSetting) this;
	}

	/**
	 * Enable tag pooling.
	 */
	@ModelNodeBinding(detypedName = "tag-pooling")
	public Boolean tagPooling() {
		return this.tagPooling;
	}

	/**
	 * Enable tag pooling.
	 */
	@SuppressWarnings("unchecked")
	public JspSetting tagPooling(Boolean value) {
		this.tagPooling = value;
		return (JspSetting) this;
	}

	/**
	 * Target VM level for compilation.
	 */
	@ModelNodeBinding(detypedName = "target-vm")
	public String targetVm() {
		return this.targetVm;
	}

	/**
	 * Target VM level for compilation.
	 */
	@SuppressWarnings("unchecked")
	public JspSetting targetVm(String value) {
		this.targetVm = value;
		return (JspSetting) this;
	}

	/**
	 * Trim some spaces from the generated Servlet.
	 */
	@ModelNodeBinding(detypedName = "trim-spaces")
	public Boolean trimSpaces() {
		return this.trimSpaces;
	}

	/**
	 * Trim some spaces from the generated Servlet.
	 */
	@SuppressWarnings("unchecked")
	public JspSetting trimSpaces(Boolean value) {
		this.trimSpaces = value;
		return (JspSetting) this;
	}

	/**
	 * Enable advertising the JSP engine in x-powered-by.
	 */
	@ModelNodeBinding(detypedName = "x-powered-by")
	public Boolean xPoweredBy() {
		return this.xPoweredBy;
	}

	/**
	 * Enable advertising the JSP engine in x-powered-by.
	 */
	@SuppressWarnings("unchecked")
	public JspSetting xPoweredBy(Boolean value) {
		this.xPoweredBy = value;
		return (JspSetting) this;
	}
}

==> config-api-0.3.9-sources.jar: org/wildfly/swarm/config/undertow/servlet_container/JspSetting.java <==
package org.wildfly.swarm.config.undertow.servlet_container;

import org.wildfly.swarm.config.runtime.Implicit;
import org.wildfly.swarm.config.runtime.ResourceType;
import org.wildfly.swarm.config.runtime.ModelNodeBinding;
/**
 * JSP container configuration.
 */
@ResourceType("setting")
@Implicit
public class JspSetting<T extends JspSetting> {

	private String key;
	private Integer checkInterval;
	private Boolean development;
	private Boolean disabled;
	private Boolean displaySourceFragment;
	private Boolean dumpSmap;
	private Boolean errorOnUseBeanInvalidClassAttribute;
	private Boolean generateStringsAsCharArrays;
	private String javaEncoding;
	private Boolean keepGenerated;
	private Boolean mappedFile;
	private Integer modificationTestInterval;
	private Boolean optimizeScriptlets;
	private Boolean recompileOnFail;
	private String scratchDir;
	private Boolean smap;
	private String sourceVm;
	private Boolean tagPooling;
	private String targetVm;
	private Boolean trimSpaces;
	private Boolean xPoweredBy;

	public JspSetting() {
		this.key = "jsp";
	}

	public String getKey() {
		return this.key;
	}

	/**
	 * Check interval for JSP updates using a background thread.
	 */
	@ModelNodeBinding(detypedName = "check-interval")
	public Integer checkInterval() {
		return this.checkInterval;
	}

	/**
	 * Check interval for JSP updates using a background thread.
	 */
	@SuppressWarnings("unchecked")
	public JspSetting checkInterval(Integer value) {
		this.checkInterval = value;
		return (JspSetting) this;
	}

	/**
	 * Enable Development mode which enables reloading JSP on-the-fly
	 */
	@ModelNodeBinding(detypedName = "development")
	public Boolean development() {
		return this.development;
	}

	/**
	 * Enable Development mode which enables reloading JSP on-the-fly
	 */
	@SuppressWarnings("unchecked")
	public JspSetting development(Boolean value) {
		this.development = value;
		return (JspSetting) this;
	}

	/**
	 * Enable the JSP container.
	 */
	@ModelNodeBinding(detypedName = "disabled")
	public Boolean disabled() {
		return this.disabled;
	}

	/**
	 * Enable the JSP container.
	 */
	@SuppressWarnings("unchecked")
	public JspSetting disabled(Boolean value) {
		this.disabled = value;
		return (JspSetting) this;
	}

	/**
	 * When a runtime error occurs, attempts to display corresponding JSP source fragment
	 */
	@ModelNodeBinding(detypedName = "display-source-fragment")
	public Boolean displaySourceFragment() {
		return this.displaySourceFragment;
	}

	/**
	 * When a runtime error occurs, attempts to display corresponding JSP source fragment
	 */
	@SuppressWarnings("unchecked")
	public JspSetting displaySourceFragment(Boolean value) {
		this.displaySourceFragment = value;
		return (JspSetting) this;
	}

	/**
	 * Write SMAP data to a file.
	 */
	@ModelNodeBinding(detypedName = "dump-smap")
	public Boolean dumpSmap() {
		return this.dumpSmap;
	}

	/**
	 * Write SMAP data to a file.
	 */
	@SuppressWarnings("unchecked")
	public JspSetting dumpSmap(Boolean value) {
		this.dumpSmap = value;
		return (JspSetting) this;
	}

	/**
	 * Enable errors when using a bad class in useBean.
	 */
	@ModelNodeBinding(detypedName = "error-on-use-bean-invalid-class-attribute")
	public Boolean errorOnUseBeanInvalidClassAttribute() {
		return this.errorOnUseBeanInvalidClassAttribute;
	}

	/**
	 * Enable errors when using a bad class in useBean.
	 */
	@SuppressWarnings("unchecked")
	public JspSetting errorOnUseBeanInvalidClassAttribute(Boolean value) {
		this.errorOnUseBeanInvalidClassAttribute = value;
		return (JspSetting) this;
	}

	/**
	 * Generate String constants as char arrays.
	 */
	@ModelNodeBinding(detypedName = "generate-strings-as-char-arrays")
	public Boolean generateStringsAsCharArrays() {
		return this.generateStringsAsCharArrays;
	}

	/**
	 * Generate String constants as char arrays.
	 */
	@SuppressWarnings("unchecked")
	public JspSetting generateStringsAsCharArrays(Boolean value) {
		this.generateStringsAsCharArrays = value;
		return (JspSetting) this;
	}

	/**
	 * Specify the encoding used for Java sources.
	 */
	@ModelNodeBinding(detypedName = "java-encoding")
	public String javaEncoding() {
		return this.javaEncoding;
	}

	/**
	 * Specify the encoding used for Java sources.
	 */
	@SuppressWarnings("unchecked")
	public JspSetting javaEncoding(String value) {
		this.javaEncoding = value;
		return (JspSetting) this;
	}

	/**
	 * Keep the generated Servlets.
	 */
	@ModelNodeBinding(detypedName = "keep-generated")
	public Boolean keepGenerated() {
		return this.keepGenerated;
	}

	/**
	 * Keep the generated Servlets.
	 */
	@SuppressWarnings("unchecked")
	public JspSetting keepGenerated(Boolean value) {
		this.keepGenerated = value;
		return (JspSetting) this;
	}

	/**
	 * Map to the JSP source.
	 */
	@ModelNodeBinding(detypedName = "mapped-file")
	public Boolean mappedFile() {
		return this.mappedFile;
	}

	/**
	 * Map to the JSP source.
	 */
	@SuppressWarnings("unchecked")
	public JspSetting mappedFile(Boolean value) {
		this.mappedFile = value;
		return (JspSetting) this;
	}

	/**
	 * Minimum amount of time between two tests for updates, in seconds.
	 */
	@ModelNodeBinding(detypedName = "modification-test-interval")
	public Integer modificationTestInterval() {
		return this.modificationTestInterval;
	}

	/**
	 * Minimum amount of time between two tests for updates, in seconds.
	 */
	@SuppressWarnings("unchecked")
	public JspSetting modificationTestInterval(Integer value) {
		this.modificationTestInterval = value;
		return (JspSetting) this;
	}

	/**
	 * If JSP scriptlets should be optimised to remove string concatenation
	 */
	@ModelNodeBinding(detypedName = "optimize-scriptlets")
	public Boolean optimizeScriptlets() {
		return this.optimizeScriptlets;
	}

	/**
	 * If JSP scriptlets should be optimised to remove string concatenation
	 */
	@SuppressWarnings("unchecked")
	public JspSetting optimizeScriptlets(Boolean value) {
		this.optimizeScriptlets = value;
		return (JspSetting) this;
	}

	/**
	 * Retry failed JSP compilations on each request.
	 */
	@ModelNodeBinding(detypedName = "recompile-on-fail")
	public Boolean recompileOnFail() {
		return this.recompileOnFail;
	}

	/**
	 * Retry failed JSP compilations on each request.
	 */
	@SuppressWarnings("unchecked")
	public JspSetting recompileOnFail(Boolean value) {
		this.recompileOnFail = value;
		return (JspSetting) this;
	}

	/**
	 * Specify a different work directory.
	 */
	@ModelNodeBinding(detypedName = "scratch-dir")
	public String scratchDir() {
		return this.scratchDir;
	}

	/**
	 * Specify a different work directory.
	 */
	@SuppressWarnings("unchecked")
	public JspSetting scratchDir(String value) {
		this.scratchDir = value;
		return (JspSetting) this;
	}

	/**
	 * Enable SMAP.
	 */
	@ModelNodeBinding(detypedName = "smap")
	public Boolean smap() {
		return this.smap;
	}

	/**
	 * Enable SMAP.
	 */
	@SuppressWarnings("unchecked")
	public JspSetting smap(Boolean value) {
		this.smap = value;
		return (JspSetting) this;
	}

	/**
	 * Source VM level for compilation.
	 */
	@ModelNodeBinding(detypedName = "source-vm")
	public String sourceVm() {
		return this.sourceVm;
	}

	/**
	 * Source VM level for compilation.
	 */
	@SuppressWarnings("unchecked")
	public JspSetting sourceVm(String value) {
		this.sourceVm = value;
		return (JspSetting) this;
	}

	/**
	 * Enable tag pooling.
	 */
	@ModelNodeBinding(detypedName = "tag-pooling")
	public Boolean tagPooling() {
		return this.tagPooling;
	}

	/**
	 * Enable tag pooling.
	 */
	@SuppressWarnings("unchecked")
	public JspSetting tagPooling(Boolean value) {
		this.tagPooling = value;
		return (JspSetting) this;
	}

	/**
	 * Target VM level for compilation.
	 */
	@ModelNodeBinding(detypedName = "target-vm")
	public String targetVm() {
		return this.targetVm;
	}

	/**
	 * Target VM level for compilation.
	 */
	@SuppressWarnings("unchecked")
	public JspSetting targetVm(String value) {
		this.targetVm = value;
		return (JspSetting) this;
	}

	/**
	 * Trim some spaces from the generated Servlet.
	 */
	@ModelNodeBinding(detypedName = "trim-spaces")
	public Boolean trimSpaces() {
		return this.trimSpaces;
	}

	/**
	 * Trim some spaces from the generated Servlet.
	 */
	@SuppressWarnings("unchecked")
	public JspSetting trimSpaces(Boolean value) {
		this.trimSpaces = value;
		return (JspSetting) this;
	}

	/**
	 * Enable advertising the JSP engine in x-powered-by.
	 */
	@ModelNodeBinding(detypedName = "x-powered-by")
	public Boolean xPoweredBy() {
		return this.xPoweredBy;
	}

	/**
	 * Enable advertising the JSP engine in x-powered-by.
	 */
	@SuppressWarnings("unchecked")
	public JspSetting xPoweredBy(Boolean value) {
		this.xPoweredBy = value;
		return (JspSetting) this;
	}
}
